@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0205';
+our $VERSION = '0.0206';
 
 use Moo;
 use strictures 2;
@@ -264,7 +264,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 SYNOPSIS
 
@@ -307,12 +307,11 @@ This module does a few simple things:
 
 4. It allows searching by ids, keys, notes, and chords.
 
-The BWV and titles were collected from an old Internet Archive of
-C<jsbchorales.net> and filled-in from L<https://bach-chorales.com/>.
-The keys were computed with a L<music21|https://web.mit.edu/music21/>
-python program, and if missing filled-in again from
-L<https://bach-chorales.com/>.  Check out the links in the
-L</SEE ALSO> section for more information.
+The BWV and titles were collected from an Internet Archive and
+filled-in from L<https://bach-chorales.com/>.  The keys were computed
+with a L<music21|https://web.mit.edu/music21/> program, and if missing
+filled-in again from L<https://bach-chorales.com/>.  Check out the
+links in the L</SEE ALSO> section for more information.
 
 =head1 ATTRIBUTES
 
@@ -395,15 +394,18 @@ is the dataset itself.
 L<https://web.archive.org/web/20140515065053/http://www.jsbchorales.net/bwv.shtml>
 was the original site.
 
+L<http://www.bach-chorales.com/BachChorales.htm>
+is a more modern site.
+
+L<https://github.com/ology/Bach-Chorales/>
+is a web app that displays chord transitions with this module.
+
 L<https://github.com/ology/Bach-Chorales/blob/master/bin/key.py>
 is a program written to extract the key signature.
 
 L<https://github.com/ology/Bach-Chorales/blob/master/chorales.zip>
 are the collected MIDI files and PDF transcriptions.
 
-L<http://www.bach-chorales.com/BachChorales.htm>
-is a Dancer2 web app that displays chord transitions.
-
 =head1 THANK YOU
 
 Dan Book (L<DBOOK|https://metacpan.org/author/DBOOK>)
